`pipe-cleaner` is a library of common, useful extensions to the [Pipe](https://pypi.org/project/pipe/) library.

Installation
============

`pipe-cleaner` is [available on PyPI](https://pypi.org/project/pipe-cleaner/). Use your favourite package manager:

```
pip install pipe-cleaner
```

```
poetry add pipe-cleaner
```


Usage
=====

_TBD_
